@@ -19,7 +19,22 @@ ReadOnlyGridDemo::ReadOnlyGridDemo(const Glib::RefPtr<Gnome::Gda::Dict>& dict):
                                                  "As no modification query is provided, the data is read-only."));
 
   Glib::RefPtr<Gnome::Gda::Query> query = Gnome::Gda::Query::create(dict);
-  query->set_sql_text("SELECT * FROM products");
+
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  try
+  {
+    query->set_sql_text("SELECT * FROM products");
+  }
+  catch(const Glib::Error& e)
+  {
+    std::cerr << e.what() << std::endl;
+  }
+#else
+  std::auto_ptr<Glib::Error> error;
+  query->set_sql_text("SELECT * FROM products", error);
+  if(error.get() != NULL)
+    std::cerr << error->what() << std::endl;
+#endif
 
   Glib::RefPtr<Gnome::Gda::DataModelQuery> model = Gnome::Gda::DataModelQuery::create(query);
   Gnome::Db::Grid* grid = Gtk::manage(new Gnome::Db::Grid(model));
